==> bfilter-0.10.1.tar.gz: bfilter-0.10.1/main/HtmlResponseFilter.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef HTMLRESPONSEFILTER_H_
#define HTMLRESPONSEFILTER_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "ResponseFilterBase.h"
#include "ResponseFilterChain.h"
#include "NonCopyable.h"
#include "RequestPtr.h"
#include <string>

class HtmlProcessor;
class ResponseErrorInitiator;
class HttpResponseMetadata;

class HtmlResponseFilter :
	public ResponseFilterBase,
	private NonCopyable
{
public:
	HtmlResponseFilter(
		ResponseFilterChain& filter_chain, HtmlProcessor& processor,
		ConstRequestPtr const& request, bool xhtml_content);
	
	virtual ~HtmlResponseFilter();
	
	void processMetadata(std::auto_ptr<HttpResponseMetadata> metadata);
	
	void processBodyData(SplittableBuffer& data, bool eof);
private:
	HtmlProcessor& m_rProcessor;
};

#endif

==> bfilter_1.0.9.orig.tar.gz: bfilter-1.0.9/main/HtmlResponseFilter.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef HTMLRESPONSEFILTER_H_
#define HTMLRESPONSEFILTER_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "ResponseFilterBase.h"
#include "ResponseFilterChain.h"
#include "NonCopyable.h"
#include "RequestPtr.h"
#include <string>

class HtmlProcessor;
class ResponseErrorInitiator;
class HttpResponseMetadata;

class HtmlResponseFilter : public ResponseFilterBase
{
	DECLARE_NON_COPYABLE(HtmlResponseFilter)
public:
	HtmlResponseFilter(
		ResponseFilterChain& filter_chain, HtmlProcessor& processor,
		ConstRequestPtr const& request, bool xhtml_content);
	
	virtual ~HtmlResponseFilter();
	
	void processMetadata(std::auto_ptr<HttpResponseMetadata> metadata);
	
	void processBodyData(SplittableBuffer& data, bool eof);
private:
	HtmlProcessor& m_rProcessor;
};

#endif
